local DG = DoomGuy

local WEAPONTOP = 0
local WEAPONBOTTOM = 128
local RAISESPEED = 6
local LOWERSPEED = 6

DG.OverrideHUDs = {"score", "time", "rings", "lives", "textspectator", "weaponrings"}

local compatible_characters = {
	["doomguy"] = true
}

function DG.PlayerIsDoomGuy(player)
	return compatible_characters[skins[player.skin].name] or nil
end

function DG.Flash(mobj, amount)
	if mobj.subsector and mobj.subsector.valid and mobj.subsector.sector and mobj.subsector.sector.valid then
		if (mobj.subsector.sector.lightlevel < amount) then
			P_SpawnLightningFlash(mobj.subsector.sector)
			mobj.subsector.sector.lightlevel = amount
		end
		
		for fof in mobj.subsector.sector.ffloors() do
			if not fof.valid or not (fof.flags & FF_EXISTS) then continue end
			if not fof.sector.valid then return end
			
			if (fof.sector.lightlevel < amount) then
				P_SpawnLightningFlash(fof.sector)
				fof.sector.lightlevel = amount
			end
		end
	end
end

function DG.FlashRadius(mobj, amount, radius, amount, angle_modifier)
	for angle = 0, amount - 1, 1 do
		local xoffset = FixedMul(radius, sin(angle * angle_modifier))
		local yoffset = FixedMul(radius, cos(angle * angle_modifier))
		local mobj = P_SpawnMobjFromMobj(mobj, xoffset, yoffset, 0, MT_DFLASHHELPER)
		mobj.fuse = 2
		DG.Flash(mobj, amount)
	end
end

function DG.PlayerFlash(player)
	DG.FlashRadius(player.realmo, 200, 128 * FU, 8, ANGLE_45)
	DG.FlashRadius(player.realmo, 200, 256 * FU, 8, ANGLE_45)
	DG.FlashRadius(player.realmo, 200, 512 * FU, 16, ANGLE_22h)
	DG.Flash(player.realmo, 200)
end

function DG.SetupPlayer(player)
	if not player.doom then
		player.doom = {}
	end

	player.doom.health = 100 * FU
	player.doom.health_max = 100 * FU
	
	player.doom.armor = 0
	player.doom.armor_max = 100 * FU
	player.doom.armor_efficiency = 0
	
	player.doom.oxygen = 100 * FU
	player.doom.oxygen_max = 100 * FU
	
	player.doom.pending_weapon = WEAPONSTATE_NONE
	player.doom.pending_weapon_slot = 0

	player.doom.weapon = WEAPONSTATE_NONE
	player.doom.weapon_slot = 0
	player.doom.weapon_slot_index = 0
	
	player.doom.state = WEAPONSTATE_CHANGE
	player.doom.state_index = 1
	player.doom.tick = 0
	player.doom.tick_speed = 1
	
	player.doom.weapon_sprites = {}
	for index = 0, 2, 1 do
		player.doom.weapon_sprites[index] = {sprite = SPR_NULL, frame = A}
	end
	
	player.doom.weapon_xoffset = 0
	player.doom.weapon_yoffset = WEAPONBOTTOM
	
	player.doom.firing = false
	player.doom.refire = 0
	
	player.doom.previous_buttons = 0
	player.doom.previous_momz = 0
	
	player.doom.crouching = false
	player.doom.sprinting = false
	player.doom.dead = false
	player.doom.gibbed = false
	
	player.doom.attacker = nil
	player.doom.attacker_time = 0
	player.doom.invulnerability_tick = 0
	player.doom.hurted_flash = 0
	player.doom.item_flash = 0
	player.doom.rings = 0
	
	if not player.doom.powers then
		player.doom.powers = {}
	end
	
	player.doom.ammo = {}
	player.doom.ammo_max = {}
	for index, ammo in pairs(DG.Ammos) do
		player.doom.ammo[index] = 0
		player.doom.ammo_max[index] = ammo.max_amount
	end
	player.doom.ammo["clip"] = 50
	
	player.doom.weapons = {}
	player.doom.weapons["fist"] = true
	player.doom.weapons["pistol"] = true
	player.doom.pending_weapon = "pistol"
	player.doom.pending_weapon_slot = 2
end